pub struct OpcWriteValues {
pub response_level: ResponseLevel,
pub proportional: f32,
pub integral: f32,
pub derivative: f32,
}Expand description
The literal values to write back to the DCS/PLC for one PidParameters — see
opc_write_values. Distinct from PidParameters because integral/derivative may
differ from the calculated values for controller types that don’t use one or both terms.
Fields
response_level: ResponseLevelproportional: f32integral: f32derivative: f32Trait Implementations
Sourceimpl Clone for OpcWriteValues
impl Clone for OpcWriteValues
Sourcefn clone(&self) -> OpcWriteValues
fn clone(&self) -> OpcWriteValues
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OpcWriteValues
Sourceimpl Debug for OpcWriteValues
impl Debug for OpcWriteValues
Sourceimpl<'de> Deserialize<'de> for OpcWriteValues
impl<'de> Deserialize<'de> for OpcWriteValues
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for OpcWriteValues
impl PartialEq for OpcWriteValues
Sourcefn eq(&self, other: &OpcWriteValues) -> bool
fn eq(&self, other: &OpcWriteValues) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OpcWriteValues
impl Serialize for OpcWriteValues
impl StructuralPartialEq for OpcWriteValues